home | help
lizard(1)			  User Commands 		       lizard(1)

NAME
     lizard, unlizard, lizardcat - Compress or decompress .liz files

SYNOPSIS
     lizard [OPTIONS] [-|INPUT-FILE] <OUTPUT-FILE>

     unlizard is equivalent to lizard -d
     lizardcat is equivalent to lizard -dc

     When  writing  scripts  that need to decompress files, it is recommended to
     always use the name lizard with appropriate arguments (lizard -d or  lizard
     -dc) instead of the names unlizard and lizardcat.

DESCRIPTION
     lizard  is an extremely fast lossless compression algorithm, based on byte-
     aligned LZ77 family  of  compression  scheme.   lizard  offers  compression
     speeds  of  400  MB/s per core, linearly scalable with multi-core CPUs.  It
     features an extremely fast decoder, with speed in multiple GB/s  per  core,
     typically	reaching RAM speed limit on multi-core systems.  The native file
     format is the .liz format.

     lizard supports a command line syntax similar but not identical to gzip(1).
     Differences are : lizard preserve original files ; lizard file1 file2 means
     : compress file1 into file2 ; lizard file shows real-time statistics during
     compression .

     Default behaviors can be modified	by  opt-in  commands,  described  below.
     lizard --quiet --multiple more closely mimics gzip behavior.

   Concatenation of .liz files
     It  is  possible  to  concatenate .liz files as is.  lizard will decompress
     such files as if they were a single .liz file. For example:
       lizard file1  > foo.liz
       lizard file2 >> foo.liz
      then
       lizardcat foo.liz
      is equivalent to :
       cat file1 file2

OPTIONS
   Short commands concatenation
     In some cases, some options can be expressed using short command -x or long
     command --long-word .  Short commands can	be  concatenated  together.  For
     example,	-d   -c  is  equivalent  to  -dc  .   Long  commands  cannot  be
     concatenated.  They must be clearly separated by a space.

   Multiple commands
     When multiple contradictory commands are issued on  a  same  command  line,
     only the latest one will be applied.

   Operation mode
     -z, --compress
	    Compress.  This is the default operation mode when no operation mode
	    option  is	specified  , no other operation mode is implied from the
	    command name (for example, unlizard implies --decompress ), nor from
	    the input file name (for example,  a  file	extension  .liz  implies
	    --decompress  by default).	-z can also be used to force compression
	    of an already compressed .liz file.

     -d, --decompress, --uncompress
	    Decompress.  --decompress is also the  default  operation  when  the
	    input filename has an .liz extensionq

     -t, --test
	    Test  the integrity of compressed .liz files.  The decompressed data
	    is discarded.  No files are created nor removed.

   Operation modifiers
     -1
	     fast compression (default)

     -9
	     high compression

     -f, --[no-]force
	     This option has several effects:

	    *  If  the	target	file  already  exists,	overwrite   it	 without
	       prompting.

	    *  When  used with --decompress and lizard cannot recognize the type
	       of the source file, copy  the  source  file  as	is  to	standard
	       output.	This allows lizardcat --force to be used like cat(1) for
	       files that have not been compressed with lizard.

     -c, --stdout, --to-stdout
	     force write to standard output, even if it is the console

     -m, --multiple
	     Multiple file names.
	     By default, the second filename is used as the destination filename
	    for the compressed file.
	     With  -m  ,  you can specify any number of input filenames. Each of
	    them will be compressed independently, and	the  resulting	name  of
	    each compressed file will be filename.liz

     -B#
	     block size [4-7](default : 7)
	     B1 = 128KB, B2=256KB, B3=1MB, B4=4MB, B5=16MB, B6=64MB, B7=256MB

     -BD
	     block dependency (improves compression ratio on small blocks)

     --[no-]frame-crc
	     select frame checksum (default:enabled)

     --[no-]content-size
	     header includes original size (default:not present)
	     Note : this option can only be activated when the original size can
	    be	determined,  hence for a file. It won't work with unknown source
	    size, such as stdin or pipe.

     --[no-]sparse
	     sparse mode support (default:enabled on file, disabled on stdout)

     -l
	     use Legacy format (useful for Linux Kernel compression)

   Other options
     -v, --verbose
	     verbose mode

     -q, --quiet
	     suppress  warnings  and  real-time  statistics;  specify  twice  to
	    suppress errors too

     -h/-H
	     display help/long help and exit

     -V, --version
	     display Version number and exit

     -k, --keep
	     Don't delete source file.	This is default behavior anyway, so this
	    option is just for compatibility with gzip/xz.

     -b
	     benchmark file(s)

     -i#
	     iteration loops [1-9](default : 3), benchmark mode only

BUGS
     Report bugs at: https://github.com/inikep/lizard/issues

AUTHOR
     Yann Collet

lizard				   2015-03-21			       lizard(1)

home | help